@@ -8,4 +8,8 @@ import cv2
 from PIL import Image
 import shutil
 import glob
-import ffmpy
\ No newline at end of file
+import ffmpy
+
+from StyleTransferTensorFlow import extract
+from StyleTransferTensorFlow import style
+from StyleTransferTensorFlow import convert
\ No newline at end of file
