@@ -1,7 +1,7 @@
 import cv2
 
 def ExtractFrames(video_path, directory, extractframerate=30):
-  vidcap = cv2.VideoCapture(vidpath)
+  vidcap = cv2.VideoCapture(video_path)
 
   success,image = vidcap.read()
   count = 0
